`Get.matrix.data.for.classid` <-
function(Table.gene.class, classid, data.matrix, ontology="Funcat", ratio.negative=0, common.genes=NULL, seed=1, include.unknown=FALSE){
  set.seed(seed);
  cl.genes <- Extract.class(Table.gene.class,classid);
  positive.gene.names <- as.character(cl.genes$gene.names);
	all.gene.names <- row.names(Table.gene.class);
	negative.gene.names <- all.gene.names[-cl.genes$indices];
		
	if (include.unknown==FALSE) {
	    if ((ontology=="BP") || (ontology=="MF") || (ontology=="CC")) {
	     v <- apply(as.matrix(Table.gene.class),1,sum);
		   gene.names.unknown.class <- all.gene.names[which(v==1)];
		   negative.gene.names <- setdiff(negative.gene.names,gene.names.unknown.class); 
	    } else { # Funcat ontology
			  gene.names.unknown.class <- character(0);
			  buffer <- all.gene.names[which(Table.gene.class[,"98"] == 1)];
		    gene.names.unknown.class <- c(gene.names.unknown.class, buffer);
				buffer <- all.gene.names[which(Table.gene.class[,"99"] == 1)];
		    gene.names.unknown.class <- c(gene.names.unknown.class, buffer);
				negative.gene.names <- setdiff(negative.gene.names,gene.names.unknown.class);			 
			}
	}	
	
	if (is.null(common.genes)) {
	  #gene.names <- c(positive.gene.names, negative.gene.names); 
	  gene.names.data<-rownames(data.matrix);
	
	  positive.available.genes <- intersect(positive.gene.names,gene.names.data);
	  negative.available.genes <- intersect(negative.gene.names,gene.names.data);
	} else {
	  positive.available.genes <- intersect(positive.gene.names,common.genes);
	  negative.available.genes <- intersect(negative.gene.names,common.genes);	
	}
	
	if (ratio.negative!=0) {
	   np <- length(positive.available.genes);
		 tot.n <- length(negative.available.genes);
		 nn <- round(np*ratio.negative);
		 if ((np==0) || (nn==0))
	      stop("Get.matrix.data.for.classid: there are no examples for at least one of the classes");
		 ind <- trunc(runif(nn, min=1, max=tot.n+1));
		 negative.available.genes <- negative.available.genes[ind];	
	}	
	
	np <- length(positive.available.genes);
	nn <- length(negative.available.genes);
	  
	
  exprs.values <- data.matrix[c(positive.available.genes,negative.available.genes),];
  exprs.values[is.na(exprs.values)] <- 0;
	
	y <- as.factor(c(rep(1,np),rep(2,nn)));
	return (list(X=exprs.values,labels=y, n.pos=np, n.neg=nn));
}

