`Get.matrix.data.without.ancestors` <-
function(Table.gene.class, classid, data.matrix, ontology="Funcat", ratio.negative=0, common.genes=NULL, seed=1, include.unknown=FALSE){
  set.seed(seed);
	
	if (ontology=="Funcat") {
	   ancestor.id <- GetFuncatAncestors(classid);
		 if (include.unknown) { 
		   no.ancestor.id <- c("00");
		 } else no.ancestor.id <- c("00", "98", "99");
		 ancestor.id <- setdiff (ancestor.id, no.ancestor.id);
	}  else if (ontology=="BP") {
  	 ancestor.id <-  AnnotationDbi::get(classid, GOBPANCESTOR);
		 ancestor.id <- setdiff (ancestor.id, c("all","GO:0008150")); 
	}  else if (ontology=="MF") {
  	 ancestor.id <-  AnnotationDbi::get(classid, GOMFANCESTOR);
		 ancestor.id <- setdiff (ancestor.id, c("all","GO:0003674")); 
	}  else if (ontology=="CC") {
  	 ancestor.id <-  AnnotationDbi::get(classid, GOCCANCESTOR);
		 ancestor.id <- setdiff (ancestor.id, c("all","GO:0005575")); 
	}  else
  	 stop("Get.matrix.data.without.ancestors: ontology not valid");
	
	cl.genes <- Extract.class(Table.gene.class,classid);
  positive.gene.names <- as.character(cl.genes$gene.names);
	not.negative.gene.names <- positive.gene.names;
	all.gene.names <- row.names(Table.gene.class);
	for (i in 1:length(ancestor.id)) {
	   buffer <- all.gene.names[which(Table.gene.class[,ancestor.id[i]] == 1)];
		 not.negative.gene.names <- c(not.negative.gene.names, buffer);
	}
	not.negative.gene.names <- unique(not.negative.gene.names);
  negative.gene.names <- setdiff(all.gene.names, not.negative.gene.names);
	
	# with GO ontologies the genes with unknown class are all genes with only 1 label, corresponding to the root of the ontology
	# Hence if we do not want include genes belonging to unknown classes, we nee to remove the genes labeled with only 1 class
	if ((include.unknown==FALSE) && ((ontology=="BP") || (ontology=="MF") || (ontology=="CC"))) {
	  v <- apply(as.matrix(Table.gene.class),1,sum);
		gene.names.unknown.class <- all.gene.names[which(v==1)];
		negative.gene.names <- setdiff(negative.gene.names,gene.names.unknown.class);	
	}
	
	if (is.null(common.genes)) {
	  #gene.names <- c(positive.gene.names, negative.gene.names); 
	  gene.names.data<-rownames(data.matrix);
	
	  positive.available.genes <- intersect(positive.gene.names,gene.names.data);
	  negative.available.genes <- intersect(negative.gene.names,gene.names.data);
	} else {
	  positive.available.genes <- intersect(positive.gene.names,common.genes);
	  negative.available.genes <- intersect(negative.gene.names,common.genes);	
	}
	
	if (ratio.negative!=0) {
	   np <- length(positive.available.genes);
		 tot.n <- length(negative.available.genes);
		 nn <- round(np*ratio.negative);
		 if ((np==0) || (nn==0))
	      stop("Get.matrix.data.for.classid: there are no examples for at least one of the classes");
		 if (nn < tot.n) {
		   ind <- sample(tot.n,nn);
		   negative.available.genes <- negative.available.genes[ind];	
		}
	}	
	
	np <- length(positive.available.genes);
	nn <- length(negative.available.genes);
	
	if ((np==0) || (nn==0))
	  stop("Get.matrix.data.without.ancestors: number of positive or negative examples equal to 0.");
	  
	
  exprs.values <- data.matrix[c(positive.available.genes,negative.available.genes),];
  exprs.values[is.na(exprs.values)] <- 0;
	
	y <- as.factor(c(rep(1,np),rep(2,nn)));
	return (list(X=exprs.values,labels=y, n.pos=np, n.neg=nn));
}

