\name{Get.matrix.data.for.classid}
\alias{Get.matrix.data.for.classid}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Data matrix construction for a binary classification problem: negatives as not positive }
\description{
  This function builds a data set for a specific class within the FunCat taxonomy or GO.
	The positive classes are assigned according the specified GO/Funcat class, while the negative examples are 
  all the others not labelled as positive.
}
\usage{
Get.matrix.data.for.classid(Table.gene.class, classid, data.matrix, ontology = "Funcat", ratio.negative = 0, common.genes = NULL, seed = 1, include.unknown = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{Table.gene.class}{ a data frame with columns corresponding to Funcat or GO classes and rows to a given gene. If a gene
  belongs to the Funcat/GO class the corresponding column is set to 1 otherwise to 0. }
  \item{classid}{ GO/FunCat ID of the the class to be extracted from Table.gene.class }
  \item{data.matrix}{ matrix of the  data from which  genes of the positive and negative classes are extracted. Rows correspond to genes and columns to the features
	                    associated to each gene }
  \item{ontology}{ a character vector corresponding to the selected ontology: Funcat  (default), BP, MF, CC }
  \item{ratio.negative}{ the proportion of negative examples w.r.t the positives. If 0 (def.) all the available negative examples are used }
  \item{common.genes}{ character vector: if it set to NULL (default) only the genes common to the given ontology and data set are considered; 
  otherwise only the genes of the common.genes are considered }
  \item{seed}{ seed for the random generator }
  \item{include.unknown}{ boolean. If FALSE (def) classes labeled as unknown are not included as possible negative examples }
}
\details{
For a gene and its associate data x with multilabel \eqn{y \in {0,1}^N} where \eqn{N} is the number of nodes classes,
we have that the positive examples for node \eqn{i} are
\deqn{D(i)^+ = \{ x |  y_i = 1\}} while the negatives are \deqn{D(i)^- = \{ x |  y_i = 0\}}.
  The data set given as input must be in matrix format, with genes on the rows and variables associated to genes as columns;
the rows of the data matrix needs to be named with the gene names (e.g. ORF ID for yeast or Entrez Gene IDs for human or mouse).
Possible data could be, e.g., gene expression or phylogenetic data
It may be used with both GO and Funcat ontologies and with any species.
The positive classes are assigned according the specified GO/Funcat class, while the negative examples are 
all the others not labelled as positive. It is possible to select a random subset of the negatives of a specified size.
The data  are associated to the selected genes and are returned together with the labels of the classes.
The function considers only gene names that are common to the ontologies and the available data.
N.B. : gene names of the data matrix need to be of the same type of the gene names stored in the rows of \code{Table.gene.class}.
For instance they must be both systematic names of the genes for the yeast or Locus Link identifiers for human gene names.
  The argument \code{common.genes}  is a character vector with the names of genes common to multiple data sets. 
  If it set to NULL (default) only the genes common to the given ontology and data set are considered; 
  otherwise only the genes of the common.genes are considered: this may be useful only if you want to use multiple data sets
  and the function \code{Get.all.common.genes} has been previously called to select the genes common to multiple data sets.
}
\value{
   A list with four elements:
  \item{X }{matrix of the data values (rows are genes, columns variables)}
  \item{labels }{a factor with the labels of the classes: 1 for classid (positives), 2 for negatives (not belonging to classid).}
	\item{n.pos }{number of positive examples}
	\item{n.neg }{number of negaive examples}
}
\seealso{ \code{\link{Get.matrix.data.from.parent.only}},  \code{\link{Get.matrix.data.without.ancestors}} }
\examples{
# building a data set of gene expression data for the yeast (considering only TAS annotations) for the class "GO:0000902", 
# with a number of negative examples equal to the number of positive ones
Yeast.specific.TAS <- Get.yeast.GO.specific.classes(evidence="TAS");
Yeast.general.TAS <- Get.yeast.GO.all.classes(Yeast.specific.TAS);
Yeast.GO.Table.TAS <- Build.GO.class.labels(Yeast.general.TAS);
library(yeastCC);
data.expression <- exprs(spYCCES);
data.expression.specific.class <-Get.matrix.data.for.classid(Yeast.GO.Table.TAS, classid="GO:0000902", data.expression, ontology = "BP", ratio.negative = 1);
# setting a number of negative examples equal to the three times the number of positive ones
data.expression.specific.class.3 <-Get.matrix.data.for.classid(Yeast.GO.Table.TAS, classid="GO:0000902", data.expression, ontology = "BP", ratio.negative = 3);
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ manip }
