\name{Funcat.navigation}
\alias{Funcat.navigation}
\alias{Funcat.parent}
\alias{Funcat.child}
\alias{Funcat.ancestors}
\alias{GetFuncatParent}
\alias{GetFuncatAncestors}
\alias{GetFuncatDepth}
\alias{Is.leaf}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Navigation in FunCat trees: getting children, parent and ancestors }
\description{
  Functions to navigate inside FunCat trees and to obtain children, parent and ancestors of a given node.
	Also functions giving the depth of each node and to know if a node is a leaf or an internal node are given.
	Two types of functions to navigate the trees: the first set is based on a given FunCat tree, the second set
	exploits the name of the FunCat nodes to obtain children, parent and ancestors.	
}
\usage{
Funcat.child(g, node)
Funcat.parent(gup, node)
Funcat.ancestors(gup, node)
GetFuncatParent(funcatID)
GetFuncatAncestors(funcatID)
GetFuncatDepth(funcatID)
Is.leaf(x, g)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{g}{ graph of the Funcat tree. It must have edges from parent to children }
  \item{gup}{ graph of the Funcat tree. It must have edges from children to parent }
  \item{node}{ vector of the nodes (FuncatID) }
	\item{funcatID}{Funcat ID}
	\item{x}{Funcat ID}
}
\details{
  The function \code{Funcat.child} provides the children of a given node.
	The functions \code{Funcat.parent} and \code{GetFuncatParent} provide the parent of a given node.
	The functions \code{Funcat.ancestors} and \code{GetFuncatAncestors} provide the ancestors of a given node.
	\code{GetFuncatDepth} provides the depth of a given node and \code{Is.leaf} reveals if a given node is a
	leaf.
	The main difference between the navigation functions are related the structure of a given tree and on
	the name of the FunCat class. In the first case results depends on the structure of the tree given as 
	argument to the function. In the second case results depends only on the overall "universal" FunCat tree.
	The second type of functions are faster.
}
\value{
  A vector of the children (\code{Funcat.child}), parent (\code{Funcat.parent}, \code{GetFuncatParent}), 
	ancestors (\code{Funcat.ancestors},\code{GetFuncatAncestors})  of funcatID.
	The function \code{Is.leaf} returns TRUE if x is a leaf, otherwise FALSE.
	The function \code{GetFuncatDepth} returns the depth of the node.
}
\examples{
t <- Do.universal.tree.Funcat();
t.up <- Do.universal.tree.Funcat.up();
Funcat.child(t, "01");
Funcat.ancestors(t.up,"01.03.01.01");
GetFuncatAncestors("01.03.01.01");
Funcat.parent(t.up, "01.03.01.01");
Is.leaf("01", t);
GetFuncatDepth("01.03.01.01");
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ graphs }
